@@ -207,7 +207,7 @@ def rot_mat_and_cam_center_to_ext_mat(rotation_mat, camera_center, batch_shape=N
     return _ivy.matmul(rotation_mat, identity_w_cam_center)
 
 
-def depth_to_pixel_coords(depth, uniform_pixel_coords=None, batch_shape=None, image_dims=None):
+def depth_to_ds_pixel_coords(depth, uniform_pixel_coords=None, batch_shape=None, image_dims=None):
     """
     Get depth scaled homogeneous pixel co-ordinates image :math:`\mathbf{X}_p\in\mathbb{R}^{h×w×3}` from depth image
     :math:`\mathbf{X}_d\in\mathbb{R}^{h×w×1}`.\n
@@ -241,7 +241,49 @@ def depth_to_pixel_coords(depth, uniform_pixel_coords=None, batch_shape=None, im
     return uniform_pixel_coords * depth
 
 
-def cam_to_pixel_coords(coords_wrt_cam, calib_mat, batch_shape=None, image_dims=None):
+def depth_to_radial_depth(depth, inv_calib_mat, uniform_pixel_coords=None, batch_shape=None, image_dims=None):
+    """
+    Get radial depth image :math:`\mathbf{X}_{rd}\in\mathbb{R}^{h×w×1}` from depth image
+    :math:`\mathbf{X}_d\in\mathbb{R}^{h×w×1}`.\n
+
+    :param depth: Depth image *[batch_shape,h,w,1]*
+    :type depth: array
+    :param inv_calib_mat: Inverse calibration matrix *[batch_shape,3,3]*
+    :type inv_calib_mat: array
+    :param uniform_pixel_coords: Image of homogeneous pixel co-ordinates. Created if None. *[batch_shape,h,w,3]*
+    :type uniform_pixel_coords: array, optional
+    :param batch_shape: Shape of batch. Inferred from inputs if None.
+    :type batch_shape: sequence of ints, optional
+    :param image_dims: Image dimensions. Inferred from inputs in None.
+    :type image_dims: sequence of ints, optional
+    :return: Radial depth image *[batch_shape,h,w,1]*
+    """
+
+    if batch_shape is None:
+        batch_shape = depth.shape[:-3]
+
+    if image_dims is None:
+        image_dims = depth.shape[-3:-1]
+
+    # shapes as list
+    batch_shape = list(batch_shape)
+    image_dims = list(image_dims)
+
+    # BS x H x W x 3
+    if uniform_pixel_coords is None:
+        uniform_pixel_coords = create_uniform_pixel_coords_image(image_dims, batch_shape, dev_str=_ivy.dev_str(depth))
+
+    # BS x H x W x 3
+    ds_pixel_coords = depth_to_ds_pixel_coords(depth, uniform_pixel_coords, batch_shape, image_dims)
+
+    # BS x H x W x 3
+    cam_coords = ds_pixel_to_cam_coords(ds_pixel_coords, inv_calib_mat, batch_shape, image_dims)[..., 0:3]
+
+    # BS x H x W x 1
+    return _ivy.reduce_sum(cam_coords**2, -1, keepdims=True)**0.5
+
+
+def cam_to_ds_pixel_coords(coords_wrt_cam, calib_mat, batch_shape=None, image_dims=None):
     """
     Get depth scaled homogeneous pixel co-ordinates image :math:`\mathbf{X}_p\in\mathbb{R}^{h×w×3}` from camera-centric
     homogeneous co-ordinates image :math:`\mathbf{X}_c\in\mathbb{R}^{h×w×4}`.\n
@@ -276,15 +318,15 @@ def cam_to_pixel_coords(coords_wrt_cam, calib_mat, batch_shape=None, image_dims=
     return _ivy_pg.transform(coords_wrt_cam, calib_mat, batch_shape, image_dims)
 
 
-def pixel_to_cam_coords(pixel_coords, inv_calib_mat, batch_shape=None, image_dims=None, dev_str=None):
+def ds_pixel_to_cam_coords(ds_pixel_coords, inv_calib_mat, batch_shape=None, image_dims=None, dev_str=None):
     """
     Get camera-centric homogeneous co-ordinates image :math:`\mathbf{X}_c\in\mathbb{R}^{h×w×4}` from
     depth scaled homogeneous pixel co-ordinates image :math:`\mathbf{X}_p\in\mathbb{R}^{h×w×3}`.\n
     `[reference] <localhost:63342/ivy/docs/source/references/mvg_textbook.pdf#page=173>`_
     page 155, matrix inverse of equation 6.3
 
-    :param pixel_coords: Depth scaled homogeneous pixel co-ordinates image *[batch_shape,h,w,3]*
-    :type pixel_coords: array
+    :param ds_pixel_coords: Depth scaled homogeneous pixel co-ordinates image *[batch_shape,h,w,3]*
+    :type ds_pixel_coords: array
     :param inv_calib_mat: Inverse calibration matrix *[batch_shape,3,3]*
     :type inv_calib_mat: array
     :param batch_shape: Shape of batch. Inferred from inputs if None.
@@ -297,20 +339,20 @@ def pixel_to_cam_coords(pixel_coords, inv_calib_mat, batch_shape=None, image_dim
     """
 
     if batch_shape is None:
-        batch_shape = pixel_coords.shape[:-3]
+        batch_shape = ds_pixel_coords.shape[:-3]
 
     if image_dims is None:
-        image_dims = pixel_coords.shape[-3:-1]
+        image_dims = ds_pixel_coords.shape[-3:-1]
 
     if dev_str is None:
-        dev_str = _ivy.dev_str(pixel_coords)
+        dev_str = _ivy.dev_str(ds_pixel_coords)
 
     # shapes as list
     batch_shape = list(batch_shape)
     image_dims = list(image_dims)
 
     # BS x H x W x 3
-    cam_coords = _ivy_pg.transform(pixel_coords, inv_calib_mat, batch_shape, image_dims)
+    cam_coords = _ivy_pg.transform(ds_pixel_coords, inv_calib_mat, batch_shape, image_dims)
 
     # BS x H x W x 4
     return _ivy.concatenate((cam_coords, _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
@@ -396,7 +438,7 @@ def cam_to_world_coords(coords_wrt_cam, inv_ext_mat, batch_shape=None, image_dim
     return _ivy.concatenate((world_coords, _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
 
 
-def world_to_pixel_coords(coords_wrt_world, full_mat, batch_shape=None, image_dims=None):
+def world_to_ds_pixel_coords(coords_wrt_world, full_mat, batch_shape=None, image_dims=None):
     """
     Get depth scaled homogeneous pixel co-ordinates image :math:`\mathbf{X}_p\in\mathbb{R}^{h×w×3}` from world-centric
     homogeneous co-ordinates image :math:`\mathbf{X}_w\in\mathbb{R}^{h×w×4}`.\n
@@ -428,15 +470,15 @@ def world_to_pixel_coords(coords_wrt_world, full_mat, batch_shape=None, image_di
     return _ivy_pg.transform(coords_wrt_world, full_mat, batch_shape, image_dims)
 
 
-def pixel_to_world_coords(pixel_coords, inv_full_mat, batch_shape=None, image_dims=None, dev_str=None):
+def ds_pixel_to_world_coords(ds_pixel_coords, inv_full_mat, batch_shape=None, image_dims=None, dev_str=None):
     """
     Get world-centric homogeneous co-ordinates image :math:`\mathbf{X}_w\in\mathbb{R}^{h×w×4}` from depth scaled
     homogeneous pixel co-ordinates image :math:`\mathbf{X}_p\in\mathbb{R}^{h×w×3}`.\n
     `[reference] <localhost:63342/ivy/docs/source/references/mvg_textbook.pdf#page=173>`_
     combination of page 155, matrix inverse of equation 6.3, and matrix inverse of page 156, equation 6.6
 
-    :param pixel_coords: Depth scaled homogeneous pixel co-ordinates image: *[batch_shape,h,w,3]*
-    :type pixel_coords: array
+    :param ds_pixel_coords: Depth scaled homogeneous pixel co-ordinates image: *[batch_shape,h,w,3]*
+    :type ds_pixel_coords: array
     :param inv_full_mat: Inverse full projection matrix *[batch_shape,3,4]*
     :type inv_full_mat: array
     :param batch_shape: Shape of batch. Inferred from inputs if None.
@@ -449,29 +491,29 @@ def pixel_to_world_coords(pixel_coords, inv_full_mat, batch_shape=None, image_di
     """
 
     if batch_shape is None:
-        batch_shape = pixel_coords.shape[:-3]
+        batch_shape = ds_pixel_coords.shape[:-3]
 
     if image_dims is None:
-        image_dims = pixel_coords.shape[-3:-1]
+        image_dims = ds_pixel_coords.shape[-3:-1]
 
     if dev_str is None:
-        dev_str = _ivy.dev_str(pixel_coords)
+        dev_str = _ivy.dev_str(ds_pixel_coords)
 
     # shapes as list
     batch_shape = list(batch_shape)
     image_dims = list(image_dims)
 
     # BS x H x W x 4
-    pixel_coords = _ivy.concatenate((pixel_coords, _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
+    ds_pixel_coords = _ivy.concatenate((ds_pixel_coords, _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
 
     # BS x H x W x 3
-    world_coords = _ivy_pg.transform(pixel_coords, inv_full_mat, batch_shape, image_dims)
+    world_coords = _ivy_pg.transform(ds_pixel_coords, inv_full_mat, batch_shape, image_dims)
 
     # BS x H x W x 4
     return _ivy.concatenate((world_coords, _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
 
 
-def pixel_coords_to_world_ray_vectors(pixel_coords, inv_full_mat, camera_center=None, batch_shape=None, image_dims=None):
+def ds_pixel_coords_to_world_ray_vectors(ds_pixel_coords, inv_full_mat, camera_center=None, batch_shape=None, image_dims=None):
     """
     Calculate world-centric ray vector image :math:`\mathbf{RV}\in\mathbb{R}^{h×w×3}` from homogeneous pixel co-ordinate
     image :math:`\mathbf{X}_p\in\mathbb{R}^{h×w×3}`. Each ray vector :math:`\mathbf{rv}_{i,j}\in\mathbb{R}^{3}` is
@@ -480,8 +522,8 @@ def pixel_coords_to_world_ray_vectors(pixel_coords, inv_full_mat, camera_center=
     :math:`\mathbf{x}_{i,j}=\overset{\sim}{\mathbf{C}} + λ\mathbf{rv}_{i,j}`, where :math:`λ` is a scalar who's
     magnitude dictates the position of the world co-ordinate along the world ray.
 
-    :param pixel_coords: Homogeneous pixel co-ordinates image *[batch_shape,h,w,3]*
-    :type pixel_coords: array
+    :param ds_pixel_coords: Homogeneous pixel co-ordinates image *[batch_shape,h,w,3]*
+    :type ds_pixel_coords: array
     :param inv_full_mat: Inverse full projection matrix *[batch_shape,3,4]*
     :type inv_full_mat: array
     :param camera_center: Camera centers, inferred from inv_full_mat if None *[batch_shape,3,1]*
@@ -490,14 +532,14 @@ def pixel_coords_to_world_ray_vectors(pixel_coords, inv_full_mat, camera_center=
     :type batch_shape: sequence of ints, optional
     :param image_dims: Image dimensions. Inferred from inputs in None.
     :type image_dims: sequence of ints, optional
-    :return: World ray vectors *[batch_shape,h,w,4]*
+    :return: World ray vectors *[batch_shape,h,w,3]*
     """
 
     if batch_shape is None:
-        batch_shape = pixel_coords.shape[:-3]
+        batch_shape = ds_pixel_coords.shape[:-3]
 
     if image_dims is None:
-        image_dims = pixel_coords.shape[-3:-1]
+        image_dims = ds_pixel_coords.shape[-3:-1]
 
     # shapes as list
     batch_shape = list(batch_shape)
@@ -510,13 +552,50 @@ def pixel_coords_to_world_ray_vectors(pixel_coords, inv_full_mat, camera_center=
     camera_centers_reshaped = _ivy.reshape(camera_center, batch_shape + [1, 1, 3])
 
     # BS x H x W x 3
-    vectors = pixel_to_world_coords(pixel_coords, inv_full_mat, batch_shape, image_dims)[..., 0:3] \
+    vectors = ds_pixel_to_world_coords(ds_pixel_coords, inv_full_mat, batch_shape, image_dims)[..., 0:3] \
               - camera_centers_reshaped
 
     # BS x H x W x 3
     return vectors / (_ivy.reduce_sum(vectors ** 2, -1, keepdims=True) ** 0.5 + MIN_DENOMINATOR)
 
 
+def sphere_coords_to_world_ray_vectors(sphere_coords, inv_rotation_mat, batch_shape=None, image_dims=None):
+    """
+    Calculate world-centric ray vector image :math:`\mathbf{RV}\in\mathbb{R}^{h×w×3}` from camera-centric ego-sphere
+    polar co-ordinates image :math:`\mathbf{S}_c\in\mathbb{R}^{h×w×3}`. Each ray vector
+    :math:`\mathbf{rv}_{i,j}\in\mathbb{R}^{3}` is represented as a unit vector from the camera center
+    :math:`\overset{\sim}{\mathbf{C}}\in\mathbb{R}^{3×1}`, in the world frame. Co-ordinates
+    :math:`\mathbf{x}_{i,j}\in\mathbb{R}^{3}` along the world ray can then be parameterized as
+    :math:`\mathbf{x}_{i,j}=\overset{\sim}{\mathbf{C}} + λ\mathbf{rv}_{i,j}`, where :math:`λ` is a scalar who's
+    magnitude dictates the position of the world co-ordinate along the world ray.
+
+    :param sphere_coords: Camera-centric ego-sphere polar co-ordinates image *[batch_shape,h,w,3]*
+    :type sphere_coords: array
+    :param inv_rotation_mat: Inverse rotation matrix *[batch_shape,3,3]*
+    :type inv_rotation_mat: array
+    :param batch_shape: Shape of batch. Inferred from inputs if None.
+    :type batch_shape: sequence of ints, optional
+    :param image_dims: Image dimensions. Inferred from inputs in None.
+    :type image_dims: sequence of ints, optional
+    :return: World ray vectors *[batch_shape,h,w,3]*
+    """
+
+    if batch_shape is None:
+        batch_shape = sphere_coords.shape[:-3]
+
+    if image_dims is None:
+        image_dims = sphere_coords.shape[-3:-1]
+
+    # shapes as list
+    batch_shape = list(batch_shape)
+    image_dims = list(image_dims)
+
+    # BS x H x W x 3
+    cam_coords = sphere_to_cam_coords(sphere_coords, batch_shape=batch_shape, image_dims=image_dims)[..., 0:3]
+    vectors = _ivy_pg.transform(cam_coords, inv_rotation_mat, batch_shape, image_dims)
+    return vectors / (_ivy.reduce_sum(vectors ** 2, -1, keepdims=True) ** 0.5 + MIN_DENOMINATOR)
+
+
 def bilinearly_interpolate_image(image, sampling_pixel_coords, batch_shape=None, image_dims=None):
     """
     Bilinearly interpolate image :math:`\mathbf{X}\in\mathbb{R}^{h×w×d}` at sampling pixel locations
@@ -593,7 +672,7 @@ def calib_and_ext_to_full_mat(calib_mat, ext_mat):
     return _ivy.matmul(calib_mat, ext_mat)
 
 
-def cam_to_sphere_coords(cam_coords, batch_shape=None, image_dims=None):
+def cam_to_sphere_coords(cam_coords, forward_facing_z=True):
     """
     Convert camera-centric homogeneous cartesian co-ordinates image :math:`\mathbf{X}_c\in\mathbb{R}^{h×w×4}` to
     camera-centric ego-sphere polar co-ordinates image :math:`\mathbf{S}_c\in\mathbb{R}^{h×w×3}`.\n
@@ -601,37 +680,29 @@ def cam_to_sphere_coords(cam_coords, batch_shape=None, image_dims=None):
 
     :param cam_coords: Camera-centric homogeneous cartesian co-ordinates image *[batch_shape,h,w,4]*
     :type cam_coords: array
-    :param batch_shape: Shape of batch. Inferred from inputs if None.
-    :type batch_shape: sequence of ints, optional
-    :param image_dims: Image dimensions. Inferred from inputs in None.
-    :type image_dims: sequence of ints, optional
+    :param forward_facing_z: Whether to use reference frame so z is forward facing. Default is False.
+    :type forward_facing_z: bool, optional
     :return: Camera-centric ego-sphere polar co-ordinates image *[batch_shape,h,w,3]*
     """
 
-    if batch_shape is None:
-        batch_shape = cam_coords.shape[:-3]
-
-    if image_dims is None:
-        image_dims = cam_coords.shape[-3:-1]
-
-    # shapes as list
-    batch_shape = list(batch_shape)
-    image_dims = list(image_dims)
+    # BS x H x W x 3
+    if forward_facing_z:
+        cam_coords = _ivy.concatenate((cam_coords[..., 2:3], cam_coords[..., 0:1], cam_coords[..., 1:2]), -1)
+    else:
+        cam_coords = cam_coords[..., 0:3]
 
     # BS x H x W x 3
-    return _ivy.reshape(
-        _ivy_mec.cartesian_to_polar_coords(_ivy.reshape(cam_coords[..., 0:3], (-1, 3))),
-        batch_shape + image_dims + [3])
+    return _ivy_mec.cartesian_to_polar_coords(cam_coords)
 
 
-def pixel_to_sphere_coords(pixel_coords, inv_calib_mat, batch_shape=None, image_dims=None):
+def ds_pixel_to_sphere_coords(ds_pixel_coords, inv_calib_mat, batch_shape=None, image_dims=None):
     """
     Convert depth scaled homogeneous pixel co-ordinates image :math:`\mathbf{X}_p\in\mathbb{R}^{h×w×3}` to
     camera-centric ego-sphere polar co-ordinates image :math:`\mathbf{S}_c\in\mathbb{R}^{h×w×3}`.\n
     `[reference] <https://en.wikipedia.org/wiki/Spherical_coordinate_system#Cartesian_coordinates>`_
 
-    :param pixel_coords: Depth scaled homogeneous pixel co-ordinates image *[batch_shape,h,w,3]*
-    :type pixel_coords: array
+    :param ds_pixel_coords: Depth scaled homogeneous pixel co-ordinates image *[batch_shape,h,w,3]*
+    :type ds_pixel_coords: array
     :param inv_calib_mat: Inverse calibration matrix *[batch_shape,3,3]*
     :type inv_calib_mat: array
     :param batch_shape: Shape of batch. Inferred from inputs if None.
@@ -642,20 +713,20 @@ def pixel_to_sphere_coords(pixel_coords, inv_calib_mat, batch_shape=None, image_
     """
 
     if batch_shape is None:
-        batch_shape = pixel_coords.shape[:-3]
+        batch_shape = ds_pixel_coords.shape[:-3]
 
     if image_dims is None:
-        image_dims = pixel_coords.shape[-3:-1]
+        image_dims = ds_pixel_coords.shape[-3:-1]
 
     # shapes as list
     batch_shape = list(batch_shape)
     image_dims = list(image_dims)
 
     # BS x H x W x 4
-    cam_coords = pixel_to_cam_coords(pixel_coords, inv_calib_mat, batch_shape, image_dims)
+    cam_coords = ds_pixel_to_cam_coords(ds_pixel_coords, inv_calib_mat, batch_shape, image_dims)
 
     # BS x H x W x 3
-    return cam_to_sphere_coords(cam_coords, batch_shape, image_dims)
+    return cam_to_sphere_coords(cam_coords)
 
 
 def angular_pixel_to_sphere_coords(angular_pixel_coords, pixels_per_degree):
@@ -664,7 +735,7 @@ def angular_pixel_to_sphere_coords(angular_pixel_coords, pixels_per_degree):
     polar co-ordinates image :math:`\mathbf{S}_c\in\mathbb{R}^{h×w×3}`.\n
     `[reference] <https://en.wikipedia.org/wiki/Spherical_coordinate_system#Cartesian_coordinates>`_
 
-    :param angular_pixel_coords: Angular pixel co-ordinates image *[batch_shape,h,w,2]*
+    :param angular_pixel_coords: Angular pixel co-ordinates image *[batch_shape,h,w,3]*
     :type angular_pixel_coords: array
     :param pixels_per_degree: Number of pixels per angular degree
     :type pixels_per_degree: float
@@ -676,19 +747,18 @@ def angular_pixel_to_sphere_coords(angular_pixel_coords, pixels_per_degree):
     sphere_y_coords = angular_pixel_coords[..., 1:2]
     radius_values = angular_pixel_coords[..., 2:3]
 
-    sphere_x_angle_coords_in_degs = sphere_x_coords/(pixels_per_degree + MIN_DENOMINATOR) - 180
-    sphere_y_angle_coords_in_degs = sphere_y_coords/(pixels_per_degree + MIN_DENOMINATOR)
+    sphere_x_angle_coords_in_degs = (180 - sphere_x_coords/(pixels_per_degree + MIN_DENOMINATOR) % 360)
+    sphere_y_angle_coords_in_degs = (sphere_y_coords/(pixels_per_degree + MIN_DENOMINATOR) % 180)
 
     # BS x H x W x 2
-    sphere_angle_coords_in_degs = _ivy.concatenate((sphere_x_angle_coords_in_degs, sphere_y_angle_coords_in_degs),
-                                                   -1)
+    sphere_angle_coords_in_degs = _ivy.concatenate((sphere_x_angle_coords_in_degs, sphere_y_angle_coords_in_degs), -1)
     sphere_angle_coords = sphere_angle_coords_in_degs * np.pi / 180
 
     # BS x H x W x 3
     return _ivy.concatenate((sphere_angle_coords, radius_values), -1)
 
 
-def sphere_to_cam_coords(sphere_coords, batch_shape=None, image_dims=None, dev_str=None):
+def sphere_to_cam_coords(sphere_coords, forward_facing_z=True, batch_shape=None, image_dims=None, dev_str=None):
     """
     Convert camera-centric ego-sphere polar co-ordinates image :math:`\mathbf{S}_c\in\mathbb{R}^{h×w×3}` to
     camera-centric homogeneous cartesian co-ordinates image :math:`\mathbf{X}_c\in\mathbb{R}^{h×w×4}`.\n
@@ -696,6 +766,8 @@ def sphere_to_cam_coords(sphere_coords, batch_shape=None, image_dims=None, dev_s
 
     :param sphere_coords: Camera-centric ego-sphere polar co-ordinates image *[batch_shape,h,w,3]*
     :type sphere_coords: array
+    :param forward_facing_z: Whether to use reference frame so z is forward facing. Default is False.
+    :type forward_facing_z: bool, optional
     :param batch_shape: Shape of batch. Inferred from inputs if None.
     :type batch_shape: sequence of ints, optional
     :param image_dims: Image dimensions. Inferred from inputs in None.
@@ -719,13 +791,16 @@ def sphere_to_cam_coords(sphere_coords, batch_shape=None, image_dims=None, dev_s
     image_dims = list(image_dims)
 
     # BS x H x W x 3
-    cam_coords_not_homo = _ivy_mec.polar_to_cartesian_coords(sphere_coords)
+    cam_coords = _ivy_mec.polar_to_cartesian_coords(sphere_coords)
+    if forward_facing_z:
+        cam_coords = _ivy.concatenate(
+            (cam_coords[..., 1:2], cam_coords[..., 2:3], cam_coords[..., 0:1]), -1)
 
     # BS x H x W x 4
-    return _ivy.concatenate((cam_coords_not_homo, _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
+    return _ivy.concatenate((cam_coords, _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
 
 
-def sphere_to_pixel_coords(sphere_coords, calib_mat, batch_shape=None, image_dims=None):
+def sphere_to_ds_pixel_coords(sphere_coords, calib_mat, batch_shape=None, image_dims=None):
     """
     Convert camera-centric ego-sphere polar co-ordinates image :math:`\mathbf{S}_c\in\mathbb{R}^{h×w×3}` to depth scaled
     homogeneous pixel co-ordinates image :math:`\mathbf{X}_p\in\mathbb{R}^{h×w×3}`.\n
@@ -753,10 +828,10 @@ def sphere_to_pixel_coords(sphere_coords, calib_mat, batch_shape=None, image_dim
     image_dims = list(image_dims)
 
     # BS x H x W x 4
-    cam_coords = sphere_to_cam_coords(sphere_coords, batch_shape, image_dims)
+    cam_coords = sphere_to_cam_coords(sphere_coords, batch_shape=batch_shape, image_dims=image_dims)
 
     # BS x H x W x 3
-    return cam_to_pixel_coords(cam_coords, calib_mat, batch_shape, image_dims)
+    return cam_to_ds_pixel_coords(cam_coords, calib_mat, batch_shape, image_dims)
 
 
 def sphere_to_angular_pixel_coords(sphere_coords, pixels_per_degree):
@@ -782,8 +857,8 @@ def sphere_to_angular_pixel_coords(sphere_coords, pixels_per_degree):
     sphere_angle_coords_in_degs = sphere_angle_coords * 180 / np.pi
 
     # BS x H x W x 1
-    sphere_x_coords = (sphere_angle_coords_in_degs[..., 0:1] + 180) % 360 * pixels_per_degree
-    sphere_y_coords = sphere_angle_coords_in_degs[..., 1:2] % 180 * pixels_per_degree
+    sphere_x_coords = ((180 - sphere_angle_coords_in_degs[..., 0:1]) % 360) * pixels_per_degree
+    sphere_y_coords = (sphere_angle_coords_in_degs[..., 1:2] % 180) * pixels_per_degree
 
     # BS x H x W x 3
     return _ivy.concatenate((sphere_x_coords, sphere_y_coords, sphere_radius_vals), -1)
